#===============================================================================
# Ttulo: Inferncia Estatstica - Entender a Origem distribuio t de Student
# Autor : Jos Cludio Faria/UESC/DCET
# Data  : 10/12/2021 19:16:38
#===============================================================================
# Objetivos
#===============================================================================
# a) Gerar uma populao normal (parmetros definidos pelo usurio);
# b) Amostrar repetidamente a populao (definido pelo usurio);
# c) Estimar o valor t a partir de cada amostra;
# d) Plotar o histograma dos valores tcal, que deve ser semelhante a funo t
#    (parmetros definidos pelo usurio) se o nmero de
#    repeties do processo for suficiente para se aproximar do limite;
# e) Sobrepor ao histograma a funo densidade de probabilidade especfica.
#===============================================================================

#.. ___Ini opes___
mu <- 10      # M POP
s  <-  1.174  # DP POP

n    <- 10  # Tamanho da amostra
nsim <- 1e4 # Nmero de simulaes

p <- 10/100 # Probabilidade adotada na inferncia
k <- 100    # Nmero de intervalos do histograma
#.. ___Fim opes___

#.. Gerar populao e bootstrap para calcular o vetor dos valores t
m <- matrix(rnorm(n * nsim,
                  mu,
                  s),
            nrow=nsim,
            ncol=n)

tm <- apply(m,
            1,
            function(x) (mean(x) - mu)/(sd(x)/sqrt(n)))

#tm <- apply(m,
#            1,
#            function(x) (mean(x) - mu)/(s/sqrt(n)))

#.. Plotar o histograma dos valores t observados
par(mfrow=c(1, 1))
library(fdth)
plot(fdt(tm,
         k=k),
     type='d',
     xlim=c(-10, 10),
     ylim=c(0, .45),
     main="Histograma e FDP",
     xlab='t',
     ylab="F(t)")

#.. Adicionar a curva terica dos valores t
# x = t
curve(dt(x,
         df=n-1),
      add=T,
      col="red",
      lwd=3,
      n=1e3)

# Adicionar os limites para a inferncia
qtl = qt(p/2, df=n-1, lower.tail=T)
qtu = qt(p/2, df=n-1, lower.tail=F)

segments(qtl, -1, qtl, 0.4, col='red', lwd=1, lty=2)
segments(qtu, -1, qtu, 0.4, col='red', lwd=1, lty=2)

text(-5, 0.30, 'RRHo', col='red')
text(-5, 0.28, paste(100 * p/2, '%', sep=''), cex=.9, col='red')

text( 5, 0.30, 'RRHo', col='red')
text( 5, 0.28, paste(100 * p/2, '%', sep=''), cex=.9, col='red')

text( 0, 0.43, 'RAHo', col='darkgreen')

text( 6, 0.15, 'H0: t=0', pos=4)
text( 6, 0.12, 'H1: t != 0', pos=4)

#.. Adicionar a curva terica normal reduzida
curve(dnorm(x,
            mean=0,
            sd=1),
      add=T,
      col=gray(.5),
      lwd=2,
      n=1e3)
